______________________________________________________________________

name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

______________________________________________________________________

## Describe the bug

<!-- A clear and concise description of what the bug is. -->

## To Reproduce

<!--
If you use spglib's Python API, please do not use Pymatgen's wrapper to make it easier to identify your problem.
The format for crystal structures is shown here: https://spglib.readthedocs.io/en/latest/python-spglib.html#variables
If spglib returns different results by changing `symprec`, `angle_tolerance`, or `mag_symprec`, please report it too.
-->

## Expected behavior

<!-- A clear and concise description of what you expected to happen. -->

## Environment

- Python version:
- Spglib's version:

## Additional context

<!-- Add any other context about the problem here. -->
